@@ -19,6 +19,8 @@ from drf_kit.views.viewsets import (
     CachedModelViewSet,
     ReadOnlyModelViewSet,
     CachedReadOnlyModelViewSet,
+    NonDestructiveModelViewSet,
+    CachedNonDestructiveModelViewSet,
     WriteOnlyModelViewSet,
     UpsertMixin,
     BulkMixin,
@@ -29,6 +31,8 @@ __all__ = (
     "CachedNestedModelViewSet",
     "ReadOnlyNestedModelViewSet",
     "CachedReadOnlyNestedModelViewSet",
+    "NonDestructiveModelViewSet",
+    "CachedNonDestructiveModelViewSet",
     "WriteOnlyNestedModelViewSet",
     "SingleNestedModelViewSet",
     "CachedSingleNestedModelViewSet",
